package acme

import (
	"embed"
	"encoding/json"
	"log"
)

//go:embed providers.json
var providerFile embed.FS

type ProviderInfo struct {
	Type      string         `json:"type"`
	Remarks   string         `json:"remarks"`
	Doc       *ProviderDoc   `json:"doc"`
	Variables *ConfVariables `json:"variables"`
}

type ProviderDoc struct {
	Show string `json:"show"`
	Home string `json:"home"`
	Api  string `json:"api"`
	Sdk  string `json:"sdk"`
}

type ConfVariables struct {
	Info  string      `json:"info"`
	Docs  *[]string   `json:"docs"`
	Items *[]ConfItem `json:"items"`
}

type ConfItem struct {
	Name    string `json:"name"`
	Type    string `json:"type"`
	Require bool   `json:"require"`
	Info    string `json:"info"`
}

var ProviderInfoMap map[string]ProviderInfo = nil

// ProviderInfos 数组
var ProviderInfos = make([]ProviderInfo, 0)

func ListProvider() *[]ProviderInfo {
	if ProviderInfoMap == nil {
		initProvider()
	}
	return &ProviderInfos
}
func MapProvider() *map[string]ProviderInfo {
	if ProviderInfoMap == nil {
		initProvider()
	}
	return &ProviderInfoMap
}
func GetProvider(name string) *ProviderInfo {
	info := ProviderInfoMap[name]
	return &info
}

func initProvider() {
	data, err := providerFile.ReadFile("providers.json")
	if err != nil {
		log.Fatalf("Failed to read config file: %v", err)
	}
	var providers []ProviderInfo
	if err := json.Unmarshal(data, &providers); err != nil {
		log.Fatalf("Failed to parse config file: %v", err)
	}
	ProviderInfoMap = make(map[string]ProviderInfo)
	for _, provider := range providers {
		ProviderInfos = append(ProviderInfos, provider)
		ProviderInfoMap[provider.Type] = provider
	}
}
