package conf

import "log"

func Config() *AppConfig {
	return appConf
}

func EditServer(host string, port int, key string, web bool) *AppConfig {
	appConf.Server.Host = host
	appConf.Server.Port = port
	appConf.Server.Key = key
	appConf.Server.Web = web
	WriteConfig()
	return appConf
}

func EditWeb(info string) *AppConfig {
	appConf.Web.Info = info
	WriteConfig()
	return appConf
}

func ExecWeb(run bool) *AppConfig {
	appConf.Server.Web = run
	WriteConfig()
	return appConf
}

func EditTask(delay int, interval int) *AppConfig {
	appConf.Task.Delay = delay
	appConf.Task.Interval = interval
	WriteConfig()
	return appConf
}

func FindProvider(name string) (*ProviderConf, int) {
	for index, provider := range *appConf.Providers {
		if provider.Name == name {
			return &provider, index
		}
	}
	return nil, -1
}

func AddProvider(name string, typeName string, conf map[string]string) *AppConfig {
	provider, _ := FindProvider(name)
	if provider != nil {
		log.Fatal("已存在相同名称的配置")
		return nil
	}
	provider = &ProviderConf{
		Name: name,
		Type: typeName,
		Conf: conf,
	}
	providers := *appConf.Providers
	newProviders := append(providers, *provider)
	appConf.Providers = &newProviders
	return appConf
}

func EditProvider(name string, typeName string, conf map[string]string) *AppConfig {
	provider, _ := FindProvider(name)
	if provider == nil {
		log.Fatal("不存在该配置")
		return nil
	}
	provider.Type = typeName
	provider.Conf = conf
	WriteConfig()
	return appConf
}

func RmProvider(name string) *AppConfig {
	_, index := FindProvider(name)
	if index == -1 {
		log.Fatal("不存在该配置")
	}
	providers := *appConf.Providers
	newProviders := append(providers[:index], providers[index+1:]...)
	appConf.Providers = &newProviders
	return appConf
}

func FindCert(name string) (*CertConf, int) {
	for index, cert := range *appConf.Certs {
		if cert.Name == name {
			return &cert, index
		}
	}
	return nil, -1
}
func FindCertByProvider(provider string) *[]CertConf {
	var result []CertConf
	for _, cert := range *appConf.Certs {
		if cert.Provider == provider {
			result = append(result, cert)
		}
	}
	return &result
}

func AddCert(cert *CertConf) *AppConfig {
	certs := *appConf.Certs
	newCerts := append(certs, *cert)
	appConf.Certs = &newCerts
	return appConf
}
func EditCert(name string, cert *CertConf) *AppConfig {
	_, index := FindCert(name)
	if index == -1 {
		log.Fatal("不存在该配置")
	}
	certs := *appConf.Certs
	certs[index] = *cert
	appConf.Certs = &certs
	return appConf
}
func RmCert(name string) *AppConfig {
	_, index := FindCert(name)
	if index == -1 {
		log.Fatal("不存在该配置")
	}
	certs := *appConf.Certs
	newCerts := append(certs[:index], certs[index+1:]...)
	appConf.Certs = &newCerts
	return appConf
}
